# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from originstamp_client.models.usage_response import UsageResponse  # noqa: F401,E501


class DefaultUsageResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'UsageResponse',
        'error_code': 'int',
        'error_message': 'str'
    }

    attribute_map = {
        'data': 'data',
        'error_code': 'error_code',
        'error_message': 'error_message'
    }

    def __init__(self, data=None, error_code=None, error_message=None):  # noqa: E501
        """DefaultUsageResponse - a model defined in Swagger"""  # noqa: E501

        self._data = None
        self._error_code = None
        self._error_message = None
        self.discriminator = None

        if data is not None:
            self.data = data
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message

    @property
    def data(self):
        """Gets the data of this DefaultUsageResponse.  # noqa: E501

        Generic response object which contains the response data, e.g. timestamp information.  # noqa: E501

        :return: The data of this DefaultUsageResponse.  # noqa: E501
        :rtype: UsageResponse
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this DefaultUsageResponse.

        Generic response object which contains the response data, e.g. timestamp information.  # noqa: E501

        :param data: The data of this DefaultUsageResponse.  # noqa: E501
        :type: UsageResponse
        """

        self._data = data

    @property
    def error_code(self):
        """Gets the error_code of this DefaultUsageResponse.  # noqa: E501

        Contains the error of the request. If the error code is 0, everything is fine.  # noqa: E501

        :return: The error_code of this DefaultUsageResponse.  # noqa: E501
        :rtype: int
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this DefaultUsageResponse.

        Contains the error of the request. If the error code is 0, everything is fine.  # noqa: E501

        :param error_code: The error_code of this DefaultUsageResponse.  # noqa: E501
        :type: int
        """

        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this DefaultUsageResponse.  # noqa: E501

        Contains the error message, that possibly occurred. If it is empty, everything is fine.  # noqa: E501

        :return: The error_message of this DefaultUsageResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this DefaultUsageResponse.

        Contains the error message, that possibly occurred. If it is empty, everything is fine.  # noqa: E501

        :param error_message: The error_message of this DefaultUsageResponse.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DefaultUsageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
