# coding: utf-8

# flake8: noqa
"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from originstamp_client.models.default_scheduler_response import DefaultSchedulerResponse
from originstamp_client.models.default_timestamp_response import DefaultTimestampResponse
from originstamp_client.models.default_usage_response import DefaultUsageResponse
from originstamp_client.models.defaultstring import Defaultstring
from originstamp_client.models.notification import Notification
from originstamp_client.models.proof_request import ProofRequest
from originstamp_client.models.response_entity import ResponseEntity
from originstamp_client.models.scheduler_request import SchedulerRequest
from originstamp_client.models.scheduler_response import SchedulerResponse
from originstamp_client.models.timestamp_data import TimestampData
from originstamp_client.models.timestamp_request import TimestampRequest
from originstamp_client.models.timestamp_response import TimestampResponse
from originstamp_client.models.usage_response import UsageResponse
from originstamp_client.models.webhook_request import WebhookRequest
